@@ -45,9 +45,9 @@ typedef CGAL::Polygon_2<Kernel>            Polygon_2 ;
 typedef CGAL::Polygon_with_holes_2<Kernel> Polygon_with_holes_2 ;
 typedef CGAL::Straight_skeleton_2<Kernel>  Straight_skeleton_2 ;
 
+namespace { // anonymous
 
-
-template<class K>
+template<class K, bool outputDistanceInM>
 void straightSkeletonToMultiLineString(
     const CGAL::Straight_skeleton_2<K>& ss,
     MultiLineString& result,
@@ -80,6 +80,95 @@ void straightSkeletonToMultiLineString(
             continue ;
         }
 
+        LineString* ls = 0;
+        if ( outputDistanceInM ) {
+            Point pa( it->opposite()->vertex()->point() );
+            Point pb( it->vertex()->point() );
+            pa.setM( CGAL::to_double(it->opposite()->vertex()->time()) );
+            pb.setM( CGAL::to_double(it->vertex()->time()) );
+            ls = new LineString( pa, pb );
+        }
+        else {
+            ls = new LineString( it->opposite()->vertex()->point(), it->vertex()->point() );
+        }
+        algorithm::translate( *ls, translate );
+        result.addGeometry( ls );
+    }
+}
+
+/**
+ * Return abc angle in radians
+ */
+static double
+angle(const Point &a, const Point &b, const Point &c)
+{
+  Point ab( to_double(b.x() - a.x()), to_double(b.y() - a.y()) );
+  Point cb( to_double(b.x() - c.x()), to_double(b.y() - c.y()) );
+
+  double dot = ( to_double(ab.x() * cb.x() + ab.y() * cb.y()) ); /* dot product */
+  double cross = ( to_double(ab.x() * cb.y() - ab.y() * cb.x()) ); /* cross product */
+
+  double alpha = std::atan2(cross, dot);
+
+  return alpha;
+}
+
+template<class K>
+void straightSkeletonToMedialAxis(
+    const CGAL::Straight_skeleton_2<K>& ss,
+    MultiLineString& result,
+    Kernel::Vector_2& translate
+)
+{
+    typedef CGAL::Straight_skeleton_2<K> Ss ;
+
+    typedef typename Ss::Halfedge_const_handle   Halfedge_const_handle ;
+    typedef typename Ss::Halfedge_const_iterator Halfedge_const_iterator ;
+
+    // Maximum angle for touching bisectors to be
+    // retained in the ouptput. The value is in
+    // radians and represents the angle between the
+    // bisector and the defining edge.
+    //
+    // The angle between the incident edges will be double
+    // this value, so CGAL_PI / 8.0 means 45 degrees between
+    // defining edges
+    //
+    // TODO: take as parameter ?
+    //
+    // NOTE: I'm adding some tolerance here to include those angles
+    //       of exactly 45 degrees that are otherwise cut out due
+    //       to rounding precision
+    //
+    const double maxTouchingAngle = CGAL_PI / 8.0 + 1e-15;
+
+    for ( Halfedge_const_iterator it = ss.halfedges_begin(); it != ss.halfedges_end(); ++it ) {
+        // skip contour edge
+        if ( ! it->is_bisector() ) {
+            continue ;
+        }
+
+        // avoid duplicates
+        if ( it->opposite() < it ) {
+            continue ;
+        }
+
+        // Skip non-inner edges unless they bisect
+        // a low angle pair of segments
+        if ( ! it->is_inner_bisector() ) {
+
+            const Halfedge_const_handle& de1 = it->defining_contour_edge ();
+
+            // We need to check the angle formed by:
+            const Point& p1 = it->vertex()->point();
+            const Point& p2 = de1->vertex()->point();
+            const Point& p3 = de1->opposite()->vertex()->point();
+
+            double ang = angle(p1, p2, p3);
+
+            if ( ang > maxTouchingAngle ) continue ;
+        }
+
         std::auto_ptr<LineString> ls ( new LineString(
                                 Point( it->opposite()->vertex()->point() ),
                                 Point( it->vertex()->point() ) )
@@ -148,37 +237,63 @@ preparePolygon( const Polygon& poly, Kernel::Vector_2& trans )
   return ret;
 }
 
+void
+extractPolygons( const Geometry& g, std::vector< Polygon >& vect )
+{
+  switch ( g.geometryTypeId() ) {
+  case TYPE_TRIANGLE:
+      vect.push_back( g.as< Triangle >().toPolygon() );
+      break;
+  case TYPE_POLYGON:
+      vect.push_back( g.as< Polygon >() );
+      break;
+  case TYPE_MULTIPOLYGON:
+  {
+      const MultiPolygon& mp = g.as< MultiPolygon >();
+      for ( size_t i = 0; i < mp.numGeometries(); i++ ) {
+        vect.push_back( mp.polygonN( i ) );
+      }
+      break;
+  }
+  default:
+      break;
+  }
+}
+
+} // namespace anonymous
 
 ///
 ///
 ///
-std::auto_ptr< MultiLineString > straightSkeleton( const Geometry& g, bool autoOrientation, NoValidityCheck, bool innerOnly )
+std::auto_ptr< MultiLineString > straightSkeleton( const Geometry& g, bool autoOrientation, NoValidityCheck, bool innerOnly, bool outputDistanceInM )
 {
     switch ( g.geometryTypeId() ) {
     case TYPE_TRIANGLE:
-        return straightSkeleton( g.as< Triangle >().toPolygon(), autoOrientation, innerOnly ) ;
+        return straightSkeleton( g.as< Triangle >().toPolygon(), autoOrientation, innerOnly, outputDistanceInM ) ;
 
     case TYPE_POLYGON:
-        return straightSkeleton( g.as< Polygon >(), autoOrientation, innerOnly ) ;
+        return straightSkeleton( g.as< Polygon >(), autoOrientation, innerOnly, outputDistanceInM ) ;
 
     case TYPE_MULTIPOLYGON:
-        return straightSkeleton( g.as< MultiPolygon >(), autoOrientation, innerOnly ) ;
+        return straightSkeleton( g.as< MultiPolygon >(), autoOrientation, innerOnly, outputDistanceInM ) ;
 
     default:
         return std::auto_ptr< MultiLineString >( new MultiLineString );
     }
 }
 
-std::auto_ptr< MultiLineString > straightSkeleton( const Geometry& g, bool autoOrientation, bool innerOnly )
+std::auto_ptr< MultiLineString > straightSkeleton( const Geometry& g, bool autoOrientation, bool innerOnly, bool outputDistanceInM )
 {
     SFCGAL_ASSERT_GEOMETRY_VALIDITY_2D( g );
 
-    return straightSkeleton( g, autoOrientation, NoValidityCheck(), innerOnly );
+    std::auto_ptr<MultiLineString> result( straightSkeleton( g, autoOrientation, NoValidityCheck(), innerOnly, outputDistanceInM ) );
+    propagateValidityFlag( *result, true );
+    return result;
 }
 ///
 ///
 ///
-std::auto_ptr< MultiLineString > straightSkeleton( const Polygon& g, bool /*autoOrientation*/, bool innerOnly )
+std::auto_ptr< MultiLineString > straightSkeleton( const Polygon& g, bool /*autoOrientation*/, bool innerOnly, bool outputDistanceInM )
 {
     std::auto_ptr< MultiLineString > result( new MultiLineString );
 
@@ -195,7 +310,10 @@ std::auto_ptr< MultiLineString > straightSkeleton( const Polygon& g, bool /*auto
         BOOST_THROW_EXCEPTION( Exception( "CGAL failed to create straightSkeleton" ) ) ;
     }
 
-    straightSkeletonToMultiLineString( *skeleton, *result, innerOnly, trans ) ;
+    if ( outputDistanceInM )
+        straightSkeletonToMultiLineString<Kernel, true> ( *skeleton, *result, innerOnly, trans ) ;
+    else
+        straightSkeletonToMultiLineString<Kernel, false> ( *skeleton, *result, innerOnly, trans ) ;
     return result ;
 }
 
@@ -203,7 +321,7 @@ std::auto_ptr< MultiLineString > straightSkeleton( const Polygon& g, bool /*auto
 ///
 ///
 ///
-std::auto_ptr< MultiLineString > straightSkeleton( const MultiPolygon& g, bool /*autoOrientation*/, bool innerOnly )
+std::auto_ptr< MultiLineString > straightSkeleton( const MultiPolygon& g, bool /*autoOrientation*/, bool innerOnly, bool outputDistanceInM )
 {
     std::auto_ptr< MultiLineString > result( new MultiLineString );
 
@@ -216,7 +334,10 @@ std::auto_ptr< MultiLineString > straightSkeleton( const MultiPolygon& g, bool /
             BOOST_THROW_EXCEPTION( Exception( "CGAL failed to create straightSkeleton" ) ) ;
         }
 
-        straightSkeletonToMultiLineString( *skeleton, *result, innerOnly, trans ) ;
+        if ( outputDistanceInM )
+            straightSkeletonToMultiLineString<Kernel, true>( *skeleton, *result, innerOnly, trans ) ;
+        else
+            straightSkeletonToMultiLineString<Kernel, false>( *skeleton, *result, innerOnly, trans ) ;
     }
 
     return result ;
@@ -226,9 +347,25 @@ std::auto_ptr< MultiLineString > approximateMedialAxis( const Geometry& g )
 {
     SFCGAL_ASSERT_GEOMETRY_VALIDITY_2D( g );
 
-    std::auto_ptr< MultiLineString > mx =
-        straightSkeleton( g, false, NoValidityCheck(), true );
+    std::auto_ptr< MultiLineString > mx( new MultiLineString );
 
+    std::vector< Polygon > polys;
+    extractPolygons( g, polys );
+
+    for ( size_t i=0; i<polys.size(); ++i )
+    {
+        Kernel::Vector_2 trans;
+        Polygon_with_holes_2 polygon = preparePolygon( polys[i], trans );
+        boost::shared_ptr< Straight_skeleton_2 > skeleton = straightSkeleton( polygon ) ;
+
+        if ( !skeleton.get() ) {
+            BOOST_THROW_EXCEPTION( Exception( "CGAL failed to create straightSkeleton" ) ) ;
+        }
+
+        straightSkeletonToMedialAxis( *skeleton, *mx, trans ) ;
+    }
+
+    propagateValidityFlag( *mx, true );
     return mx;
 }
 
