@@ -47,34 +47,35 @@ SFCGAL_API std::auto_ptr< MultiLineString > approximateMedialAxis( const Geometr
 /**
  * @brief build a 2D straight skeleton for a Polygon
  * @todo add supports for TriangulatedSurface and PolyhedralSurface
- * @todo output M as distance to border?
  * @param g input geometry
  * @param autoOrientation check and fix polygon orientation
+ * @param outputM whether to output the distance to border as M
  * @ingroup public_api
  * @pre g is a valid geometry
  */
-SFCGAL_API std::auto_ptr< MultiLineString > straightSkeleton( const Geometry& g, bool autoOrientation = true, bool innerOnly = false ) ;
+SFCGAL_API std::auto_ptr< MultiLineString > straightSkeleton( const Geometry& g, bool autoOrientation = true, bool innerOnly = false, bool outputDistanceInM = false ) ;
 
 /**
  * @brief build a 2D straight skeleton for a Polygon
  * @param g input geometry
  * @param autoOrientation check and fix polygon orientation
+ * @param outputM whether to output the distance to border as M
  * @ingroup public_api
  * @pre g is a valid geometry
  * @warning No actual validity check is done
  */
-SFCGAL_API std::auto_ptr< MultiLineString > straightSkeleton( const Geometry& g, bool autoOrientation, NoValidityCheck, bool innerOnly = false ) ;
+SFCGAL_API std::auto_ptr< MultiLineString > straightSkeleton( const Geometry& g, bool autoOrientation, NoValidityCheck, bool innerOnly = false, bool outputDistanceInM = false ) ;
 
 /**
  * @brief build a 2D straight skeleton for a Polygon
  * @ingroup detail
  */
-SFCGAL_API std::auto_ptr< MultiLineString > straightSkeleton( const Polygon& g, bool autoOrientation = true, bool innerOnly = false ) ;
+SFCGAL_API std::auto_ptr< MultiLineString > straightSkeleton( const Polygon& g, bool autoOrientation = true, bool innerOnly = false, bool outputDistanceInM = false ) ;
 /**
  * @brief build a 2D straight skeleton for a Polygon
  * @ingroup detail
  */
-SFCGAL_API std::auto_ptr< MultiLineString > straightSkeleton( const MultiPolygon& g, bool autoOrientation = true, bool innerOnly = false ) ;
+SFCGAL_API std::auto_ptr< MultiLineString > straightSkeleton( const MultiPolygon& g, bool autoOrientation = true, bool innerOnly = false, bool outputDistanceInM = false ) ;
 
 }//namespace algorithm
 }//namespace SFCGAL
